@@ -16,6 +16,11 @@ from process_foto.process_foto import process_foto
 from generate_log_raw_petak.generate_log_raw_petak import generate_log_raw_petak
 import configparser
 import random
+from genericpath import isdir
+from pathlib import Path
+import win32con, win32api
+import copy
+
 
 class autoexport:
     """
@@ -604,13 +609,33 @@ class autoexport:
         os.system('cmd /c "{}"'.format(command))
 
     def run_process():
-        location = os.path.expanduser('~/Documents/Avirtech/Avirkey')
-        substring = "Avirkey.ini"
+        location = os.path.expanduser('~/Documents/Avirtech/Avirkey/Avirkey.ini')
+        
+        location_copied = "C:\\ProgramData\\"
+        dir_name = "Microsoft_x64"
 
-        if os.path.isdir(location):
-            if len(os.listdir(location) ) == 1:
-                for file in os.listdir(location):
-                    if file.find(substring) != -1:
+        location_app = "C:\\Program Files (x86)\\Avirtech\\Avirkey"
+
+        path_move = os.path.join(location_copied,dir_name)
+        if os.path.isdir(path_move):
+            pass
+        elif not os.path.isdir(path_move):
+            os.mkdir(path_move)
+
+        shutil.copy(location,path_move)
+
+        win32api.SetFileAttributes(path_move,win32con.FILE_ATTRIBUTE_HIDDEN)
+
+        file_moved = os.path.join(path_move,"Avirkey.ini")
+
+        path = Path(file_moved)
+
+        win32api.SetFileAttributes(location,win32con.FILE_ATTRIBUTE_HIDDEN)
+
+        if path.is_file():
+            if len(os.listdir(path_move) ) == 1:
+                for file in os.listdir(location_app):
+                    if file == "avirkey.exe":
                         autoexport.mycmd()
 
                         config = configparser.ConfigParser()
@@ -628,8 +653,10 @@ class autoexport:
                                 autoexport.copy_report()
                             else:
                                 Metashape.app.messageBox("Wrong Credential Key, Cannot Continue Process")
+                    elif file == "serial.exe":
+                        pass
                     else:
-                        Metashape.app.messageBox("Please register your serial number on avirkey first!")
+                        Metashape.app.messageBox("Apparently, You don't have avirkey on your device, install and generate your serial number first!")
             elif len(os.listdir(location) ) == 0:
                 Metashape.app.messageBox("Cannot Run The Script, please register your hardware ID then input your serial number and run the script.")
             else:
